:host(.panel-widget-box) {
    min-height: 20px;
    border: 1px solid #e3e3e3;
    border-radius: 4px;
    -webkit-box-shadow: inset 0 1px 1px rgba(0,0,0,.05);
    box-shadow: inset 0 1px 1px rgba(0,0,0,.05);
    overflow-x: hidden;
    overflow-y: hidden;
}
