:host(.card) {
    border: 1px solid rgba(0,0,0,.125);
    border-radius: 0.25rem;
}

:host(.accordion) {
    border: 1px solid rgba(0,0,0,.125);
}

.card-header {
    align-items: center;
    background-color: rgba(0, 0, 0, 0.03);
    border: 1px solid;
    border-radius: 0.25rem;
    display: inline-flex;
    justify-content: start;
    position: sticky;
    left: 0;
    width: 100%;
}

.accordion-header {
    align-items: center;
    background-color: rgba(0, 0, 0, 0.03);
    border: 1px solid;
    border-radius: 0;
    display: flex;
    justify-content: start;
    position: sticky;
    left: 0;
    width: 100%;
}

.card-button {
    background-color: transparent;
    margin-left: 0.5em;
    margin-right: 0.5em;
}

.card-header-row {
    margin-bottom: auto;
    margin-top: auto;
    position: relative !important;
}

.card-title {
    align-items: center;
    font-size: 1.4em;
    font-weight: bold;
    overflow-wrap: break-word;
}

.card-header-row > .bk {
    overflow-wrap: break-word;
    text-align: center;
}
