:root {
    --bokeh-base-font: inherit;
    --mdc-theme-primary: var(--panel-primary-color);
    --mdc-theme-primary-lightened: rgba(var(--panel-primary-rgb), 0.35);
    --mdc-theme-on-primary: var(--panel-on-primary-color);
    --mdc-theme-secondary: var(--panel-secondary-color);
    --mdc-theme-secondary-lightened: rgba(var(--panel-secondary-rgb), 0.8);
    --mdc-theme-on-secondary: var(--panel-on-secondary-color);
    --mdc-theme-background: var(--panel-background-color);
    --mdc-theme-on-background: var(--panel-on-background-color);
    --mdc-theme-surface: var(--panel-surface-color);
    --mdc-theme-on-surface: var(--panel-on-surface-color);
    --mdc-theme-text-primary-on-background: rgba(var(--panel-on-background-rgb), 0.87);
    --mdc-typography--font-family: var(--bokeh-base-font);
    --mdc-shape-small: 4px;
    --mdc-shape-medium: 4px;
    --mdc-shape-large: 0px;
}

html {
    scrollbar-face-color: var(--mdc-theme-surface);
    scrollbar-base-color: var(--mdc-theme-surface);
    scrollbar-3dlight-color: var(--mdc-theme-surface);
    scrollbar-highlight-color: var(--mdc-theme-surface);
    scrollbar-track-color: var(--mdc-theme-background);
    scrollbar-arrow-color: var(--mdc-theme-background);
    scrollbar-shadow-color: var(--mdc-theme-surface);
}

::-webkit-scrollbar {
    width: 12px;
}

::-webkit-scrollbar-track {
    background-color: var(--mdc-theme-background);
    border-radius: 10px;
}

::-webkit-scrollbar-thumb {
    background-color: var(--mdc-theme-surface);
}

body {
    background-color: var(--mdc-theme-background);
    color: var(--mdc-theme-on-background);
    display: flex;
    height: 100vh;
    margin: 0px;
    overflow-x: hidden;
    overflow-y: hidden;
}

img {
    max-width: 100%;
}

#container {
    padding: 0px;
    height: 100vh;
    width: 100vw;
    max-width: 100vw;
}

#sidebar .mdc-list {
    padding-left: 5px;
    padding-right: 5px;
}

.mdc-drawer-app-content {
    flex: auto;
    position: relative;
    overflow: hidden;
}

.mdc-drawer {
    background: var(--mdc-theme-background);
    color: var(--mdc-theme-on-background);
}

.mdc-drawer-app-content {
    margin-left: 0 !important;
}

.title-bar {
    display: contents;
    justify-content: center;
    align-content: center;
    width: 100%;
}

.app-header {
    display: contents;
    padding-left: 10px;
    font-size: 1.25em;
}

img.app-logo {
    padding-right: 10px;
    font-size: 28px;
    height: 30px;
    max-width: inherit;
    padding-top: 12px;
    padding-bottom: 6px;
}

#app-title {
    padding-right: 12px;
    padding-left: 12px;
}

.title {
    color: #fff;
    text-decoration: none;
    text-decoration-line: none;
    text-decoration-style: initial;
    text-decoration-color: initial;
    font-weight: 400;
    font-size: 1.25em;
    line-height: 2em;
    white-space: nowrap;
}

.main-content {
    height: calc(100vh - 70px);
    overflow-y: scroll;
    overflow-x: auto;
    padding: 5px 25px 0px 15px;
}

#header {
    position: absolute;
    z-index: 7;
}

#header-items {
    align-items: center;
    display: flex;
    width: 100%;
    margin-left: 25px;
}

.pn-busy-container {
    align-items: center;
    justify-content: center;
    display: flex;
}

.mdc-drawer__content {
    overflow-x: hidden;
}

.pn-modal {
    overflow-y: scroll;
    width: 100%;
    display: none;
    position: absolute;
    top: 0;
    left: 0;
}

.mdc-dialog .mdc-dialog__content {
    color: var(--mdc-theme-on-surface);
}

.pn-modal-content {
    background-color: var(--mdc-theme-surface);
    margin: auto;
    margin-top: 25px;
    margin-bottom: 25px;
    padding: 15px 20px 20px 20px;
    border: 1px solid #888;
    width: 80% !important;
}

.pn-modal-close {
    position: absolute;
    right: 25px;
    z-index: 100;
}

.pn-modal-close:hover,
.pn-modal-close:focus {
    color: #000;
    text-decoration: none;
    cursor: pointer;
}
