export default `.codehilite .hll{background-color:#ffffcc;}.codehilite{background:#f8f8f8;}.codehilite .c{color:#408080;font-style:italic;}.codehilite .err{border:1px solid #FF0000;}.codehilite .k{color:#008000;font-weight:bold;}.codehilite .o{color:#666666;}.codehilite .ch{color:#408080;font-style:italic;}.codehilite .cm{color:#408080;font-style:italic;}.codehilite .cp{color:#BC7A00;}.codehilite .cpf{color:#408080;font-style:italic;}.codehilite .c1{color:#408080;font-style:italic;}.codehilite .cs{color:#408080;font-style:italic;}.codehilite .gd{color:#A00000;}.codehilite .ge{font-style:italic;}.codehilite .gr{color:#FF0000;}.codehilite .gh{color:#000080;font-weight:bold;}.codehilite .gi{color:#00A000;}.codehilite .go{color:#888888;}.codehilite .gp{color:#000080;font-weight:bold;}.codehilite .gs{font-weight:bold;}.codehilite .gu{color:#800080;font-weight:bold;}.codehilite .gt{color:#0044DD;}.codehilite .kc{color:#008000;font-weight:bold;}.codehilite .kd{color:#008000;font-weight:bold;}.codehilite .kn{color:#008000;font-weight:bold;}.codehilite .kp{color:#008000;}.codehilite .kr{color:#008000;font-weight:bold;}.codehilite .kt{color:#B00040;}.codehilite .m{color:#666666;}.codehilite .s{color:#BA2121;}.codehilite .na{color:#7D9029;}.codehilite .nb{color:#008000;}.codehilite .nc{color:#0000FF;font-weight:bold;}.codehilite .no{color:#880000;}.codehilite .nd{color:#AA22FF;}.codehilite .ni{color:#999999;font-weight:bold;}.codehilite .ne{color:#D2413A;font-weight:bold;}.codehilite .nf{color:#0000FF;}.codehilite .nl{color:#A0A000;}.codehilite .nn{color:#0000FF;font-weight:bold;}.codehilite .nt{color:#008000;font-weight:bold;}.codehilite .nv{color:#19177C;}.codehilite .ow{color:#AA22FF;font-weight:bold;}.codehilite .w{color:#bbbbbb;}.codehilite .mb{color:#666666;}.codehilite .mf{color:#666666;}.codehilite .mh{color:#666666;}.codehilite .mi{color:#666666;}.codehilite .mo{color:#666666;}.codehilite .sa{color:#BA2121;}.codehilite .sb{color:#BA2121;}.codehilite .sc{color:#BA2121;}.codehilite .dl{color:#BA2121;}.codehilite .sd{color:#BA2121;font-style:italic;}.codehilite .s2{color:#BA2121;}.codehilite .se{color:#BB6622;font-weight:bold;}.codehilite .sh{color:#BA2121;}.codehilite .si{color:#BB6688;font-weight:bold;}.codehilite .sx{color:#008000;}.codehilite .sr{color:#BB6688;}.codehilite .s1{color:#BA2121;}.codehilite .ss{color:#19177C;}.codehilite .bp{color:#008000;}.codehilite .fm{color:#0000FF;}.codehilite .vc{color:#19177C;}.codehilite .vg{color:#19177C;}.codehilite .vi{color:#19177C;}.codehilite .vm{color:#19177C;}.codehilite .il{color:#666666;}.markdown h1{margin-block-start:0.34em;}.markdown h2{margin-block-start:0.42em;}.markdown h3{margin-block-start:0.5em;}.markdown h4{margin-block-start:0.67em;}.markdown h5{margin-block-start:0.84em;}.markdown h6{margin-block-start:1.17em;}.markdown ul{padding-inline-start:2em;}.markdown ol{padding-inline-start:2em;}.markdown strong{font-weight:600;}.markdown a{color:-webkit-link;}.markdown a{color:-moz-hyperlinkText;}:host(.markdown) .codehilite{padding:1rem 1.25rem;margin-top:1rem;margin-bottom:1rem;border-radius:0.25rem;}`
