:root[data-theme="light"], :root[data-theme="dark"] {
    --pst-color-primary: #0072B5;
    --pst-color-link: #0072B5;
    --pst-color-inline-code: #0072B5;
    --sd-color-card-border-hover: #0072B5;
}

html[data-theme=dark] .bd-content div.cell_output .text_html {
    background-color: var(--pst-color-background);
    color: var(--pst-color-text-base);
}

/* Override styling for header */
.bd-header, .bd-header .navbar-nav .dropdown .dropdown-menu {
  background-color: #343a40!important;
}

.bd-header .navbar-nav .dropdown .dropdown-menu {
    box-shadow: unset;
}

.bd-header .navbar-nav li a.nav-link {
  color: white;
}

/* Align navbar item in center */
.navbar-header-items__center {
    margin-left: 8%;
}

/* Ensure content fills full space */
.bd-main .bd-content .bd-article-container {
    max-width: unset;
}

/* Hide primary sidenav bottom section to avoid extra scroll */
.sidebar-primary-items__end.sidebar-primary__section {
    display: none;
}

.nav-link {
    white-space: nowrap;
}

.showcase-table {
    border-spacing: 15px
}

.showcase-table td {
    border: 0px;
    vertical-align: top;
}

.cell_output {
    padding-left: 0;
}

html[data-theme=dark] .bd-content div.cell_output .text_html,
html[data-theme=light] .bd-content div.cell_output .text_html {
    padding: 0;
}

@media (min-width: 1200px) {
    .bd-page-width {
	max-width: 80%;
    }

    .bd-sidebar {
	max-width: 300px;
    }

    .bd-main .bd-content .bd-article-container .bd-article {
	padding-left: 0.5rem;
	padding-top: 0.5rem;
    }
}

#scroller-right {
    max-width: 14%;
}

@media (max-width: 1400px) {
    #scroller-right {
	position: relative;
	right: unset;
	top: unset;
	max-width: 100%;
	transform: unset;
    }
}

#navbar-icon-links i.fa-github-square:before {
    color: white;
}

.fa-discourse:before {
    color: white;
}

button.toggle-button {
    display: none;
}

.toggle-hidden:not(.admonition) {
    height: 0;
}

.tag_hide-input {
    margin-bottom: 0 !important;
}

details.hide.above-input {
    display: none;
}

.toggle-hidden + .cell_output {
    margin-top: 0 !important;
}

dl.field-list {
    display: none
}

/* Improve styling */

div.cell div.cell_input {
    border: none;
}

.highlight {
    border-radius: 4px;
}

html[data-theme="light"] .highlight {
    background-color: #263238;
    color: #f8f8f2;
}

pre[id^='codecell'] {
    background-color: unset;
    border: none;
    border-radius: 0.5em;
    color: #f8f8f2;
    box-shadow: none;
    padding: 1.5em;
}

button.copybtn {
    background-color: #263238;
}

button.copybtn:hover {
    background-color: #263238;
    color: #f8f8f2;
}

.highlight button.copybtn:hover {
    background: none
}

.o-tooltip--left:after {
    background: none;
}

ul.current.nav.bd-sidenav {
    padding: 0;
}
